@@ -1,4 +1,5 @@
-print.trans <- function(x, ...) {
+"print.trans" <-
+function(x, ...) {
 ## ----------------------------------------------------------------------------
 ## Title: print.trans
 ## ----------------------------------------------------------------------------
@@ -51,3 +52,4 @@ print.trans <- function(x, ...) {
   cat("\n")
   
 } ## end of function print.trans
+
